Re-exports
pub use resolve::file_to_module;pub use list::list_modules;
Structs
- Fallible
Strategy - A
MisconfigurationStrategythat happily fails whenever an importantErris encountered. - Module
Glob Set - A compiled set of module glob patterns.
- Module
Glob SetBuilder - Builder for constructing a
ModuleGlobSet. - Module
Name - A module name, e.g.
foo.bar. - Search
Path - Unification of the various kinds of search paths that can be used to locate Python modules.
- Search
Path Iterator - Iterate over the available module-resolution search paths,
following the invariants maintained by
sys.pathat runtime: “No item is added tosys.pathmore than once.” Dynamic search paths (required for editable installs intosite-packages) are only calculated lazily. - Search
Path Settings - Configures the search paths for module resolution.
- Search
Paths - System
Module Search Paths Iter - Typeshed
Versions - Typeshed
Versions Parse Error - UseDefault
Strategy - A
MisconfigurationStrategythat refuses to ever return anErrand instead substitutes default values or skips functionality.
Enums
- Known
Module - Enumeration of various core stdlib modules in which important types are located
- Module
- Representation of a Python module.
- Module
Glob Error - Error type for module glob pattern parsing.
- Module
Name Match - The result of matching a module name against a
ModuleGlobSet. - Module
Name Resolution Error - Various ways in which resolving a
ModuleNamefrom anast::StmtImportorast::StmtImportFromnode might fail - Module
Resolve Mode - Which files should be visible when doing a module query
- PyVersion
Range - Search
Path Error - Search
Path Settings Error - Enumeration describing the various ways in which validation of the search paths options might fail.
Traits
- Db
- Misconfiguration
Strategy - Generic handling of two possible approaches to an Error:
Functions
- all_
modules - List all available modules, including all sub-modules, sorted in lexicographic order.
- file_
to_ module - Resolves the module for the file with the given id.
- list_
modules - List all available top-level modules.
- resolve_
module - Resolves a module name to a module.
- resolve_
module_ confident - Resolves a module name to a module, without desperate resolution available.
- resolve_
real_ module - Resolves a module name to a module (stubs not allowed).
- resolve_
real_ module_ confident - Resolves a module name to a module, without desperate resolution available (stubs not allowed).
- resolve_
real_ shadowable_ module - Resolves a module name to a module (stubs not allowed, some shadowing is allowed).
- search_
paths - system_
module_ search_ paths - Returns an iterator over all search paths pointing to a system path
- vendored_
typeshed_ versions