KnownModule

Enum KnownModule 

pub enum KnownModule {
Show 42 variants Builtins, Enum, Types, Typeshed, TypingExtensions, Typing, Sys, Os, Tempfile, Pathlib, Datetime, Decimal, Ipaddress, Re, Abc, Dataclasses, Functools, Collections, CollectionsAbc, CollectionsAbcInternal, Inspect, Templatelib, TypeCheckerInternals, TyExtensions, TyExtensionsInternal, TyExtensionsPydantic, ImportLib, UnittestMock, Uuid, Warnings, Numbers, Struct, PydanticConfig, PydanticFields, PydanticFunctionalValidators, PydanticMain, PydanticRootModel, PydanticSettingsMain, PydanticTypes, Pytest, PytestFixtures, PytestMarkStructures,
}
Enumeration of modules in which types with dedicated semantic behavior are located.

Variants



Builtins



Enum



Types



Typeshed



TypingExtensions



Typing



Sys



Os



Tempfile



Pathlib



Datetime



Decimal



Ipaddress



Re



Abc



Dataclasses



Functools



Collections



CollectionsAbc



CollectionsAbcInternal



Inspect



Templatelib



TypeCheckerInternals



TyExtensions



TyExtensionsInternal



TyExtensionsPydantic



ImportLib



UnittestMock



Uuid



Warnings



Numbers



Struct



PydanticConfig



PydanticFields



PydanticFunctionalValidators



PydanticMain



PydanticRootModel



PydanticSettingsMain



PydanticTypes



Pytest



PytestFixtures



PytestMarkStructures

Implementations

Source

impl KnownModule

pub const fn as_str(self) -> &'static str

pub fn name(self) -> ModuleName

pub const fn is_third_party(self) -> bool

Return true if this module is provided by a supported third-party package.

pub const fn is_builtins(self) -> bool

pub const fn is_typing(self) -> bool

pub const fn is_typing_extensions(self) -> bool

pub const fn is_ty_extensions(self) -> bool

pub const fn is_ty_extensions_internal(self) -> bool

pub const fn is_inspect(self) -> bool

pub const fn is_importlib(self) -> bool

pub const fn is_functools(self) -> bool

pub const fn is_dataclasses(self) -> bool