pub enum Module<'db> {
File(FileModule<'db>),
Namespace(NamespacePackage<'db>),
}Expand description
Representation of a Python module.
Variants
Implementations
Sourceimpl<'db> Module<'db>
impl<'db> Module<'db>
Sourcepub fn name(self, db: &'db dyn Database) -> &'db ModuleName
pub fn name(self, db: &'db dyn Database) -> &'db ModuleName
The absolute name of the module (e.g. foo.bar)
Sourcepub fn file(self, db: &'db dyn Database) -> Option<File>
pub fn file(self, db: &'db dyn Database) -> Option<File>
The file to the source code that defines this module
This is None for namespace packages.
Sourcepub fn known(self, db: &'db dyn Database) -> Option<KnownModule>
pub fn known(self, db: &'db dyn Database) -> Option<KnownModule>
Is this a module that we special-case somehow? If so, which one?
Sourcepub fn is_known(self, db: &'db dyn Database, known_module: KnownModule) -> bool
pub fn is_known(self, db: &'db dyn Database, known_module: KnownModule) -> bool
Does this module represent the given known module?
Sourcepub fn search_path(self, db: &'db dyn Database) -> Option<&'db SearchPath>
pub fn search_path(self, db: &'db dyn Database) -> Option<&'db SearchPath>
The search path from which the module was resolved.
It is guaranteed that if None is returned, then this is a namespace
package. Otherwise, this is a regular package or file module.
Sourcepub fn kind(self, db: &'db dyn Database) -> ModuleKind
pub fn kind(self, db: &'db dyn Database) -> ModuleKind
Determine whether this module is a single-file module or a package
Sourcepub fn all_submodules(self, db: &'db dyn Db) -> &'db [Module<'db>]
pub fn all_submodules(self, db: &'db dyn Db) -> &'db [Module<'db>]
Return a list of all submodules of this module.
Returns an empty list if the module is not a package, if it is an empty package,
or if it is a namespace package (one without an __init__.py or __init__.pyi file).
The names returned correspond to the “base” name of the module.
That is, {self.name}.{basename} should give the full module name.