pub enum SearchPathError {
NotADirectory(SystemPathBuf),
NoStdlibSubdirectory(SystemPathBuf),
}Variants
NotADirectory(SystemPathBuf)
The path provided by the user was not a directory
NoStdlibSubdirectory(SystemPathBuf)
The path provided by the user is a directory,
but no stdlib/ subdirectory exists.
(This is only relevant for stdlib search paths.)