pub enum SearchPathSettingsError {
InvalidSearchPath(SearchPathError),
FailedToReadVersionsFile {
path: SystemPathBuf,
error: Error,
},
VersionsParseError(TypeshedVersionsParseError),
}Expand description
Enumeration describing the various ways in which validation of the search paths options might fail.
If validation fails for a search path derived from the user settings, a message must be displayed to the user, as type checking cannot be done reliably in these circumstances.
Variants
InvalidSearchPath(SearchPathError)
FailedToReadVersionsFile
The typeshed path provided by the user is a directory,
but stdlib/VERSIONS could not be read.
(This is only relevant for stdlib search paths.)
VersionsParseError(TypeshedVersionsParseError)
The path provided by the user is a directory,
and a stdlib/VERSIONS file exists, but it fails to parse.
(This is only relevant for stdlib search paths.)