pub struct ResolverEnvironment<'db>(/* private fields */);Expand description
The Python version and search paths used to resolve modules.
Implementations
Sourceimpl ResolverEnvironment<'static>
impl ResolverEnvironment<'static>
pub fn ingredient(zalsa: &Zalsa) -> &IngredientImpl<Self>
Sourceimpl<'db> ResolverEnvironment<'db>
impl<'db> ResolverEnvironment<'db>
pub fn new<Db_, T0: Lookup<PythonVersion> + Hash, T1: Lookup<SearchPaths> + Hash>( db: &'db Db_, python_version: T0, search_paths: T1, ) -> Self
pub fn python_version<Db_>(self, db: &'db Db_) -> PythonVersion
pub fn search_paths<Db_>(self, db: &'db Db_) -> &'db SearchPaths
Sourceimpl ResolverEnvironment<'_>
impl ResolverEnvironment<'_>
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
Default debug formatting for this struct (may be useful if you define your own Debug impl)
Sourceimpl<'db> ResolverEnvironment<'db>
impl<'db> ResolverEnvironment<'db>
pub fn display_search_paths( self, db: &'db dyn Db, mode: ModuleResolveMode, ) -> impl Display