pub struct SearchPathSettings {
pub extra_paths: Vec<SystemPathBuf>,
pub src_roots: Vec<SystemPathBuf>,
pub custom_typeshed: Option<SystemPathBuf>,
pub site_packages_paths: Vec<SystemPathBuf>,
pub real_stdlib_path: Option<SystemPathBuf>,
}Expand description
Configures the search paths for module resolution.
Fields
extra_paths: Vec<SystemPathBuf>List of user-provided paths that should take first priority in the module resolution. Examples in other type checkers are mypy’s MYPYPATH environment variable, or pyright’s stubPath configuration setting.
src_roots: Vec<SystemPathBuf>The root of the project, used for finding first-party modules.
custom_typeshed: Option<SystemPathBuf>Optional path to a “custom typeshed” directory on disk for us to use for standard-library types. If this is not provided, we will fallback to our vendored typeshed stubs for the stdlib, bundled as a zip file in the binary
site_packages_paths: Vec<SystemPathBuf>List of site packages paths to use.
real_stdlib_path: Option<SystemPathBuf>Option path to the real stdlib on the system, and not some instance of typeshed.
We should ideally only ever use this for things like goto-definition, where typeshed isn’t the right answer.
Implementations
Sourceimpl SearchPathSettings
impl SearchPathSettings
pub fn new(src_roots: Vec<SystemPathBuf>) -> Self
pub fn empty() -> Self
pub fn to_search_paths<Strategy: MisconfigurationStrategy>( &self, system: &dyn System, vendored: &VendoredFileSystem, strategy: &Strategy, ) -> Result<SearchPaths, Strategy::Error<SearchPathSettingsError>>