pub enum ModuleResolveMode {
Typing,
Runtime,
RuntimeSomeShadowingAllowed,
}Expand description
Selects typing or runtime module-resolution semantics.
Variants
Typing
Resolve modules for type checking, preferring stubs over runtime implementations.
This is the “normal” mode almost everything uses, as type checkers are in fact supposed to prefer stubs over the actual implementations.
Runtime
Resolve modules to their runtime implementations without considering stubs.
This is the “goto definition” mode, where we need to ignore the typing spec and find actual implementations. When querying searchpaths this also notably replaces typeshed with the “real” stdlib.
RuntimeSomeShadowingAllowed
Like ModuleResolveMode::Runtime, but permits some modules to be shadowed.
In particular, this allows typing_extensions to be shadowed by a
non-standard library module. This is useful in the context of the LSP
where we don’t want to pretend as if these modules are always available
at runtime.