pub struct SearchPath(/* private fields */);Expand description
Unification of the various kinds of search paths that can be used to locate Python modules.
The different kinds of search paths are:
- “Extra” search paths: these go at the start of the module resolution order
- First-party search paths: the user code that we are directly invoked on.
- Standard-library search paths: these come in three different forms:
- Custom standard-library search paths: paths provided by the user pointing to a custom typeshed directory on disk
- Vendored standard-library search paths: paths pointing to a directory in the vendored zip archive.
- Real standard-library search paths: path pointing to a directory of the real python stdlib for the environment.
- Site-packages search paths: search paths that point to the
site-packagesdirectory, in which packages are installed fromPyPI. - Editable search paths: Additional search paths added to the end of the module
resolution order. We discover these by iterating through
.pthfiles in thesite-packagesdirectory and searching for lines in those.pthfiles that point to existing directories on disk. Such lines indicate editable installations, which will be appended tosys.pathat runtime, and thus should also be considered valid search paths for our purposes.
For some of the above categories, there may be an arbitrary number in any given list of search paths: for example, the “Extra” category or the “Editable” category. For the “First-party”, “Site-packages” and “Standard-library” categories, however, there will always be exactly one search path from that category in any given list of search paths.
Implementations
Sourceimpl SearchPath
impl SearchPath
Sourcepub fn is_standard_library(&self) -> bool
pub fn is_standard_library(&self) -> bool
Does this search path point to the standard library?
Sourcepub fn is_first_party(&self) -> bool
pub fn is_first_party(&self) -> bool
Is this search path in “first party” code? i.e., The end user’s project code.
Sourcepub fn is_site_packages(&self) -> bool
pub fn is_site_packages(&self) -> bool
Is the module in a site-packages directory?
Sourcepub fn describe_kind(&self) -> &'static str
pub fn describe_kind(&self) -> &'static str
Returns a string suitable for describing what kind of search path this is in user-facing diagnostics.